@@ -14,15 +14,15 @@ agraph_parents <- function(nodes, parent_edges) {
   parents <- matrix(FALSE, n, n)
   rownames(parents) <- colnames(parents) <- nodes
   for (row in 1:nrow(parent_edges)) {
-    if (!(parent_edges[row,1] %in% nodes)) {
-      stop(paste("The node", parent_edges[row,1], 
+    if (!(parent_edges[row, 1] %in% nodes)) {
+      stop(paste("The node", parent_edges[row, 1], 
                  "is used in the edges but is not specified as a node."))
     }
-    if (!(parent_edges[row,2] %in% nodes)) {
-      stop(paste("The node", parent_edges[row,2], 
+    if (!(parent_edges[row, 2] %in% nodes)) {
+      stop(paste("The node", parent_edges[row, 2], 
                  "is used in the edges but is not specified as a node."))
     }
-    parents[parent_edges[row,1], parent_edges[row,2]] <- TRUE
+    parents[parent_edges[row, 1], parent_edges[row, 2]] <- TRUE
   }
   parents
 }
@@ -73,9 +73,9 @@ agraph_weights <- function(nodes, admixture_weights, parents) {
   rownames(weights) <- colnames(weights) <- nodes
   if (!is.null(admixture_weights)) {
     for (row in 1:nrow(admixture_weights)) {
-      child <- admixture_weights[row,1]
-      parent <- admixture_weights[row,2]
-      admix_weight <- admixture_weights[row,3]
+      child <- admixture_weights[row, 1]
+      parent <- admixture_weights[row, 2]
+      admix_weight <- admixture_weights[row, 3]
       
       if (! parents[child,parent]) {
         stop(paste("There is no edge in the graph from", child, "to", parent))
@@ -169,12 +169,14 @@ admixture_proportions <- function(admix_props) matrix(ncol = 3, byrow = TRUE, da
 #' 
 #' Create an admixture graph object, an acyclic directed graph.
 #' 
-#' @param leaves                 The names of the leaves in the admixture graph.
-#' @param inner_nodes            The name of the inner nodes in the admxture graph.
+#' @param leaves                 The names of the leaves in the admixture graph. Do not use \code{(, )}
+#'                               or a single \code{R}.
+#' @param inner_nodes            The name of the inner nodes in the admxture graph.  Do not use \code{(, )}
+#'                               or a single \code{R} except for the root if you wish.
 #' @param parent_edges           The list of edges in the graph, created by 
 #'                               \code{\link{parent_edges}}.
 #' @param admixture_proportions  The list of admixture proportions; created by 
-#'                               \code{\link{admixture_proportions}}.
+#'                               \code{\link{admixture_proportions}}. Do not use \code{+, -, *, (, )}.
 #'
 #' @return An admixture graph object.
 #' 
@@ -221,7 +223,7 @@ agraph <- function(leaves, inner_nodes, parent_edges,
 #' 
 #' @param graph  An agraph object
 #' 
-#' @return  A list of trees
+#' @return A list of trees
 #' 
 #' @export
 extract_trees <- function(graph) {
@@ -235,7 +237,7 @@ extract_trees <- function(graph) {
       to_do_list[[length(to_do_list) + 1]] <- new_graphs[[1]]
       to_do_list[[length(to_do_list) + 1]] <- new_graphs[[2]]
     } else {
-      tree_list[[length(tree_list) + 1]] <- remove_joints_from_a_tree(G)
+      tree_list[[length(tree_list) + 1]] <- remove_false_leaves(remove_joints_from_a_tree(G))
     }
   }
   return(tree_list)
@@ -281,6 +283,7 @@ split_first_admixture <- function(graph) {
 
 remove_joints_from_a_tree <- function(tree) {
   # The joints must be removed one at a time.
+  still_original <- TRUE
   work_left <- TRUE
   while (work_left == TRUE) {
     nodes <- tree$nodes
@@ -289,7 +292,8 @@ remove_joints_from_a_tree <- function(tree) {
       row <- tree$parents[i, ]
       column <- tree$parents[, i]
       if (length(row[row == TRUE]) == 1 && length(column[column == TRUE]) == 1) {
-        # There is at least one joint left; we call it remove and remove it during this iteration.
+        # There is at least one joint left; we call it remove and remove it during this iteration.\
+        still_original <- FALSE
         remove <- nodes[i]
         count <- count + 1
       }
@@ -314,7 +318,43 @@ remove_joints_from_a_tree <- function(tree) {
         }
       }  
     }
-    tree <- agraph(leaves, inner_nodes, parent_edges(edge_vector))
+    if (still_original == FALSE) {
+      tree <- agraph(leaves, inner_nodes, parent_edges(edge_vector))
+    }
   }
   return(tree)
-}
\ No newline at end of file
+}
+
+remove_false_leaves <- function(tree) {
+  still_original <- TRUE
+  leaves <- tree$leaves
+  inner_nodes <- tree$inner_nodes
+  nodes <- tree$nodes
+  work_left <- TRUE
+  while (work_left == TRUE) {
+    work_left <- FALSE
+    for (i in seq(1, NROW(tree$parents))) {
+      name <- colnames(tree$parents)[i]
+      column <- tree$parents[, i]
+      if (length(column[column == TRUE]) == 0
+          && is.na(match(name, leaves)) == TRUE
+          && work_left == FALSE) {
+        still_original <- FALSE
+        work_left <- TRUE
+        inner_nodes <- inner_nodes[-which(inner_nodes == name)]
+        edge_vector <- character(0)
+        for (i in seq(1, NROW(tree$parents))) {
+          row <- tree$parents[i, ]
+          if (nodes[i] != name && length(row[row == TRUE]) == 1) {
+            edge_vector <- c(edge_vector, edge(nodes[i], nodes[which(row == TRUE)[1]]))
+          }
+        }
+      }
+    }
+    if (still_original == FALSE) {
+      tree <- agraph(leaves, inner_nodes, parent_edges(edge_vector))
+      tree <- remove_joints_from_a_tree(tree)
+    }
+  }
+  return(tree)
+}
